@@ -1,4 +1,5 @@
 from mongoengine import QuerySet
+from mongoengine.queryset.visitor import Q
 from pydantic import validator
 
 from ...base.filter import BaseFilterModel
@@ -48,9 +49,8 @@ class Filter(BaseFilterModel):
             if isinstance(field_value, Filter):
                 if not field_value.dict(exclude_none=True, exclude_unset=True):
                     continue
-                query = query.filter(
-                    **{f"{field_value.Constants.prefix}__in": field_value.filter(field_value.Constants.model.objects())}
-                )
+
+                query = query.filter(**{f"{field_name}__in": field_value.filter(field_value.Constants.model.objects())})
             else:
                 if field_name.endswith("__isnull"):
                     field_name = field_name.replace("__isnull", "")
@@ -58,6 +58,13 @@ class Filter(BaseFilterModel):
                         field_name = f"{field_name}__ne"
                     value = None
 
-                query = query.filter(**{field_name: value})
+                if field_name == self.Constants.search_field_name and hasattr(self.Constants, "search_model_fields"):
+                    search_filter = Q()
+                    for search_field in self.Constants.search_model_fields:
+                        search_filter = search_filter | Q(**{f"{search_field}__icontains": value})
+
+                    query = query.filter(search_filter)
+                else:
+                    query = query.filter(**{field_name: value})
 
         return query
